@@ -50,7 +50,7 @@ MainWindow::MainWindow(QMainWindow *parent): QMainWindow(parent)
   createMenus();
 
   createTableView(scoreList, clubList);
-  createStatusBar();
+  updateTitleBar();
 
   createLayout(centralWidget);
 }
@@ -139,20 +139,6 @@ void MainWindow::createTableView(QList<Score *> &scoreList, QList <Club *> &club
   table->horizontalHeader()->hide();
 }
 
-void MainWindow::createStatusBar()
-{
-#if 0
-  // TODO: use toolbar or buttons. Toolbar seems not to be ready and
-  // requires more work.
-  toolbar = addToolBar(tr("foo"));
-  toolbar->addAction(firstAct);
-  toolbar->addAction(lastAct);
-  toolbar->addAction(prevAct);
-  toolbar->addAction(nextAct);
-#endif
-  updateStatusBar();
-}
-
 void MainWindow::createActions()
 {
   newScoreAct = new QAction(tr("New Score"), this);
@@ -198,7 +184,7 @@ void MainWindow::createMenus()
   menu->addAction(statAct);
 }
 
-void MainWindow::updateStatusBar()
+void MainWindow::updateTitleBar()
 {
   QString title = scoreTableModel->getInfoText();
   if (title.isEmpty())
@@ -210,25 +196,25 @@ void MainWindow::updateStatusBar()
 void MainWindow::firstButtonClicked()
 {
   scoreTableModel->first();
-  updateStatusBar();
+  updateTitleBar();
 }
 
 void MainWindow::lastButtonClicked()
 {
   scoreTableModel->last();
-  updateStatusBar();
+  updateTitleBar();
 }
 
 void MainWindow::nextButtonClicked()
 {
   scoreTableModel->next();
-  updateStatusBar();
+  updateTitleBar();
 }
 
 void MainWindow::prevButtonClicked()
 {
   scoreTableModel->prev();
-  updateStatusBar();
+  updateTitleBar();
 }
 
 // FIXME: dup code from table-model.cpp
@@ -371,7 +357,7 @@ void MainWindow::newScore()
 
       // TODO: does this really work? No mem leaks?
       scoreTableModel->setScore(scoreList, score);
-      updateStatusBar();
+      updateTitleBar();
     }
   }
 }
@@ -411,7 +397,7 @@ void MainWindow::editScore()
 
     // TODO: does this really work? No mem leaks?
     scoreTableModel->setScore(scoreList, score);
-    updateStatusBar();
+    updateTitleBar();
   }
 }
 
@@ -449,7 +435,7 @@ void MainWindow::viewStatistics()
 
   QHBoxLayout *mainLayout = new QHBoxLayout(central);
   mainLayout->addLayout(infoLayout);
-  mainLayout->addLayout(buttonLayout);
+  //mainLayout->addLayout(buttonLayout);
 
   central->setLayout(mainLayout);
 
