@@ -27,9 +27,8 @@ class MainWindow : public QMainWindow
 public:
   MainWindow(QMainWindow *parent = 0);
   void createLayout(QWidget *parent = 0);
-  void createStatusBar();
   void createTableView(QList<Score *> &, QList <Club *> &);
-  void updateStatusBar();
+  void updateTitleBar();
   void loadScoreFile(QString &fileName, QList<Score *> &scoreList);
   void loadClubFile(QString &fileName, QList<Club *> &clubList);
   void saveScoreFile(QString &fileName, QList<Score *> &scoreList);
