@@ -12,14 +12,21 @@
 #include "table-model.h"
 
 QString empty("");
-
-QColor colorHoleBg(Qt::darkGray);
+#define SC_BLUE_THEME
+QColor colorHoleBg(26, 26, 26);
 QColor colorHoleFg(Qt::yellow);
-QColor colorBirdie(102, 102, 255);
-QColor colorPar(Qt::green);
-QColor colorBogey(Qt::darkGreen);
-QColor colorDoubleBogey(Qt::red);
-QColor colorBad(Qt::red);
+QColor colorBirdie(00, 0x99, 00);
+QColor colorPar(Qt::black);
+#ifdef SC_ORANGE_THEME
+QColor colorBogey(0xfc, 0xaf, 0x3e);
+QColor colorDoubleBogey(0xf5, 0x79, 0x00);
+QColor colorBad(0xce, 0x5c, 0x00);
+#endif
+#ifdef SC_BLUE_THEME
+QColor colorBogey(0x20, 0x4a, 0x87);
+QColor colorDoubleBogey(0x34, 0x65, 0xa4);
+QColor colorBad(0x72, 0x9f, 0xcf);
+#endif
 QColor colorSubTotal(Qt::black);
 QColor colorTotal(Qt::black);
 
@@ -361,7 +368,7 @@ QVariant ScoreTableModel::headerData(int section, Qt::Orientation orientation, i
   if (orientation == Qt::Horizontal)
     return QVariant();
 
-#if 1
+#if 0
   if (role == Qt::BackgroundRole) {
     QColor colorHoleBg(Qt::darkGray);
     QBrush brush(colorHoleBg);
